@@ -63,7 +63,7 @@ public:
   {
   public:
     typedef Tuple_size_type size_type;
-    Tuple(const Result *r, size_type i) : m_Home(r), m_Index(i) {}
+    Tuple(const Result *r, Result::size_type i) : m_Home(r), m_Index(i) {}
     ~Tuple() {} // Yes Scott Meyers, you're absolutely right[1]
 
     inline Field operator[](size_type) const;				//[t1]
@@ -91,7 +91,7 @@ public:
   class PQXX_LIBEXPORT Field : private Tuple
   {
   public:
-    using Tuple::size_type;
+    typedef size_t size_type;
 
     Field(const Tuple &R, Tuple::size_type C) : Tuple(R), m_Col(C) {}	//[t1]
 
@@ -234,7 +234,7 @@ public:
   size_type capacity() const { return size(); }				//[t20]
 
   const Tuple operator[](size_type i) const { return Tuple(this, i); }	//[t2]
-  const Tuple at(size_type i) const;					//[t10]
+  const Tuple at(size_type) const;					//[t10]
 
   void clear() { LoseRef(); }						//[t20]
 
@@ -251,7 +251,11 @@ public:
 
   /// If command was INSERT of 1 row, return oid of inserted row
   /** Returns InvalidOid otherwise. */
-  Oid InsertedOid() const { return PQoidValue(m_Result); }		//[]
+  Oid InsertedOid() const { return PQoidValue(m_Result); }		//[13]
+
+  /// If command was INSERT, UPDATE, or DELETE, return number of affected rows
+  /*** Returns zero for all other commands. */
+  size_type AffectedRows() const;					//[t7]
 
 private:
   PGresult *m_Result;
@@ -348,7 +352,7 @@ inline Result::const_iterator Result::end() const
   return const_iterator(this, size()); 
 }
 
-} // namespace
+} // namespace pqxx
 
 
 /* 
